==> sife-0.0.20.tgz: package/tasks/extractrulesvars.js <==

module.exports = function (grunt) {
    grunt.task.registerMultiTask('extractrulesvars', 'Apply rework plugins', function() {
        var css = require('css');
        this.files.forEach(function (filePair) {

            filePair.src.forEach(function (file) {
                grunt.log.write('Extracting from ' + file+'...');

                var extractedCss = [];
                var cssString = grunt.file.read(file);
                var obj = css.parse(cssString);

                obj.stylesheet.rules.forEach(function(rule){
                    if(rule.type==='rule' && rule.declarations && rule.declarations.length>0){
                        // find if a declaration of that rule contains a var();
                        rule.declarations.forEach(function(declaration){
                            if(!declaration.value){
                                //console.log('empty declaration '+rule.selectors.join(',')+': '+declaration.property);
                                return;
                            }
                            if(declaration.value.substr(0,4)==='var('){
                                extractedCss.push(rule.selectors.join(',')+'{'+declaration.property+':'+declaration.value+'}');
                            }
                        });
                    }
                });

                grunt.log.ok();

                grunt.log.write('  Extracted '+extractedCss.length+' declarations');


                grunt.file.write(file+'.dynamic.css', extractedCss.join('\n'));


            });

        });



    });
}

==> sife-0.0.44.tgz: package/tasks/extractrulesvars.js <==

module.exports = function (grunt) {
    grunt.task.registerMultiTask('extractrulesvars', 'Apply rework plugins', function() {
        var css = require('css');
        this.files.forEach(function (filePair) {

            filePair.src.forEach(function (file) {
                grunt.log.write('Extracting from ' + file+'...');

                var extractedCss = [];
                var cssString = grunt.file.read(file);
                var obj = css.parse(cssString);

                obj.stylesheet.rules.forEach(function(rule){
                    if(rule.type==='rule' && rule.declarations && rule.declarations.length>0){
                        // find if a declaration of that rule contains a var();
                        rule.declarations.forEach(function(declaration){
                            if(!declaration.value){
                                //console.log('empty declaration '+rule.selectors.join(',')+': '+declaration.property);
                                return;
                            }

                            if(declaration.value.indexOf('var(')>-1 && !(rule.selectors.length===1 && rule.selectors[0]===':root')){
                                extractedCss.push(rule.selectors.join(',')+'{'+declaration.property+':'+declaration.value+'}');
                            }
                        });
                    }
                });

                grunt.log.ok();

                grunt.log.write('  Extracted '+extractedCss.length+' declarations');


                grunt.file.write(file+'.dynamic.css', extractedCss.join('\n'));


            });

        });



    });
}
